@@ -16,7 +16,7 @@ Usage::
     session_client: QLDBClient = session.client("qldb")
     ```
 """
-from mypy_boto3_qldb.client import QLDBClient as Client, QLDBClient
+from mypy_boto3_qldb.client import QLDBClient, QLDBClient as Client
 
 
 __all__ = ("Client", "QLDBClient")
